@@ -502,7 +502,7 @@ notify_notification_new_with_status_icon(const gchar *summary,
                                          const gchar *icon,
                                          GtkStatusIcon *status_icon)
 {
-	g_return_val_if_fail(status_icon == NULL, NULL);
+	g_return_val_if_fail(status_icon != NULL, NULL);
 	g_return_val_if_fail(GTK_IS_STATUS_ICON(status_icon), NULL);
 
 	return g_object_new(NOTIFY_TYPE_NOTIFICATION,
@@ -631,7 +631,7 @@ notify_notification_attach_to_status_icon(NotifyNotification *notification,
 								  (gpointer)&priv->status_icon);
 	}
 
-	g_object_notify(G_OBJECT(notification), "attach-icon");
+	g_object_notify(G_OBJECT(notification), "status-icon");
 }
 #endif /* HAVE_STATUS_ICON */
 
@@ -675,6 +675,8 @@ _close_signal_handler(DBusGProxy *proxy, guint32 id,
 {
 	if (id == notification->priv->id)
 		g_signal_emit(notification, signals[SIGNAL_CLOSED], 0);
+
+	notification->priv->id = 0;
 }
 
 static void
@@ -901,7 +903,7 @@ _gvalue_array_append_byte_array(GValueArray *array, guchar *bytes, gsize len)
 		return FALSE;
 	}
 
-	g_value_init(value, dbus_g_type_get_collection("GArray", G_TYPE_CHAR));
+	g_value_init(value, DBUS_TYPE_G_UCHAR_ARRAY);
 	g_value_set_boxed_take_ownership(value, byte_array);
 	g_value_array_append(array, value);
 
@@ -961,7 +963,7 @@ notify_notification_set_icon_from_pixbuf(NotifyNotification *notification,
 
 	value = g_new0(GValue, 1);
 	g_value_init(value, G_TYPE_VALUE_ARRAY);
-	g_value_set_boxed(value, image_struct);
+	g_value_set_boxed_take_ownership(value, image_struct);
 
 	g_hash_table_insert(notification->priv->hints,
 						g_strdup("icon_data"), value);
